@@ -37,6 +37,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "shlvl",
     "singularity",
     "kubernetes",
+    "nats",
     "directory",
     "vcsh",
     "fossil_branch",
@@ -64,6 +65,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "elm",
     "erlang",
     "fennel",
+    "gleam",
     "golang",
     "gradle",
     "haskell",
@@ -76,6 +78,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "nim",
     "nodejs",
     "ocaml",
+    "odin",
     "opa",
     "perl",
     "php",
